﻿using System.Collections.ObjectModel;
using System.IO;
using BeeCoders.Tools.Wpf.Infrastructure;

namespace BeeCoders.Tools.Wpf.FileExplorer
{
	public class DriveViewModel : ItemViewModel
	{
		public bool IsFtpDrive { get; set; }
		public bool IsReady { get; set; }
		public bool ShowDirectories { get; set; }
		public bool ShowFiles { get; set; }
		public DriveInfo DriveInfo { get; set; }

		private bool isExpanded;
		public bool IsExpanded
		{
			get { return isExpanded; }
			set
			{
				if (value != isExpanded)
				{
					isExpanded = value;
					RaisePropertyChanged("IsExpanded");

					if (FileExplorerViewModel.Instance.ShowDirectories)
					{
						foreach (var child in Childs)
						{
							if (child is DirectoryViewModel)
							{
								((DirectoryViewModel)child).LoadChilds(FileExplorerViewModel.Instance.ShowFiles);
							}
						}
					}
					else
					{
						Childs.Clear();
					}

				}
			}
		}

		public new object ImageName
		{
			get
			{
				if (IsFtpDrive) return "../Images/HD 340.ico";

				if (!IsReady) return "../Images/HD 340.ico";

				if (DriveInfo.DriveType == DriveType.Fixed) return "../Images/HD 336.ico";
				if (DriveInfo.DriveType == DriveType.Network) return "../Images/Network 389.ico";
				if (DriveInfo.DriveType == DriveType.CDRom) return "../Images/DVD 75.ico";
				if (DriveInfo.DriveType == DriveType.Removable) return "../Images/Removable.ico";
				if (DriveInfo.DriveType == DriveType.Ram) return "../Images/Removable.ico";

				return "../Images/HD 336.ico";
			}
		}

		public ObservableCollectionEx<ViewModelBase> Childs { get; set; }

		public DriveViewModel(string name, string fullPath, DriveInfo driveInfo,  bool showDirectories, bool showFiles)
		{
			DriveInfo = driveInfo;
			IsReady = driveInfo.IsReady;
			IsFtpDrive = false;
			Name = name;
			FullPath = fullPath;

			

			HasCheckbox = IsReady;
			ShowDirectories = showDirectories;
			ShowFiles = showFiles;

			Childs = new ObservableCollectionEx<ViewModelBase>();

			if (showDirectories && IsReady) LoadChilds(showFiles);
		}

		public DriveViewModel(string name, string fullPath, bool showDirectories, bool showFiles)
		{
			DriveInfo = null;
			IsReady = true;
			IsFtpDrive = true;
			Name = name;
			FullPath = fullPath;



			HasCheckbox = IsReady;
			ShowDirectories = showDirectories;
			ShowFiles = showFiles;

			Childs = new ObservableCollectionEx<ViewModelBase>();

			if (showDirectories && IsReady) LoadChilds(showFiles);
		}

		public void UpdateView()
		{
			foreach (ViewModelBase child in Childs)
			{
				child.RaisePropertyChanged("HasCheckbox");
				child.RaisePropertyChanged("ShowIcons");

				if (child is DirectoryViewModel)
					((DirectoryViewModel)child).UpdateView();
			}

		}

		public void LoadChilds(bool showFiles)
		{
			if (!IsFtpDrive)
			{
				LoadChildsFileDrive(showFiles);
			}
			else
			{
				LoadChildsFtpDrive(showFiles);
			}
		}

		private void LoadChildsFileDrive(bool showFiles)
		{
			try
			{
				foreach (string directory in Directory.GetDirectories(Name))
				{
					var directoryInfo = new DirectoryInfo(directory);
					Childs.Add(new DirectoryViewModel(directory, directoryInfo.Name,showFiles));
				}

				if (showFiles)
				{
					foreach (string file in Directory.GetFiles(Name))
					{
						var fileInfo = new FileInfo(file);
						Childs.Add(new FileViewModel(file, fileInfo.Name));
					}
				}
			}
			catch (IOException)
			{
				
				
			}
			
		}

		private void LoadChildsFtpDrive(bool showFiles)
		{
			

		}
	}

}
